/**
 * A helper class for calculating the elapsed time between frames.
 *
 * Handles the case, where the browser tab is not in focus and `requestAnimationFrame`
 * does not get called for performance reasons. In this case, the return deltaTime won't be
 * an unreasonably large value.
 */
export declare class DeltaTimeCalculator {
    private previousTime;
    private visibilityChangeHandler;
    constructor();
    /**
     * Return the elapsed time in **milliseconds** since the previous call of this
     * method by subtracting the previously given `currentTime` argument from the
     * current `currentTime` argument.
     *
     * Takes visibilitychange events into account.
     *
     * @param currentTime Current time acquired e.g. with `requestAnimationFrame`.
     */
    getNextDeltaTime(currentTime: DOMHighResTimeStamp): DOMHighResTimeStamp;
    destroy(): void;
    private handleVisibilityChange;
}
//# sourceMappingURL=delta-time-calculator.d.ts.map